summaryrefslogtreecommitdiffstats
path: root/tools/designer/plugins
diff options
context:
space:
mode:
Diffstat (limited to 'tools/designer/plugins')
-rw-r--r--tools/designer/plugins/cppeditor/yyreg.cpp6
-rw-r--r--tools/designer/plugins/dlg/dlg2ui.cpp2
-rw-r--r--tools/designer/plugins/glade/glade2ui.cpp2
-rw-r--r--tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp4
-rw-r--r--tools/designer/plugins/kdevdlg/main.cpp2
-rw-r--r--tools/designer/plugins/rc/main.cpp2
-rw-r--r--tools/designer/plugins/rc/rc2ui.cpp4
7 files changed, 11 insertions, 11 deletions
diff --git a/tools/designer/plugins/dlg/dlg2ui.cpp b/tools/designer/plugins/dlg/dlg2ui.cpp
index 66a485a..c309eb2 100644
--- a/tools/designer/plugins/dlg/dlg2ui.cpp
+++ b/tools/designer/plugins/dlg/dlg2ui.cpp
@@ -1617,7 +1617,7 @@ QStringList Dlg2Ui::convertQtArchitectDlgFile( const QString& fileName )
outf.setName( outFileName );
if ( !outf.open(IO_WriteOnly) ) {
- tqWarning( "dlg2ui: Could not open output file '%s'",
+ qWarning( "dlg2ui: Could not open output file '%s'",
outFileName.latin1() );
return QStringList();
}
diff --git a/tools/designer/plugins/glade/glade2ui.cpp b/tools/designer/plugins/glade/glade2ui.cpp
index 07efef2..39ff5e8 100644
--- a/tools/designer/plugins/glade/glade2ui.cpp
+++ b/tools/designer/plugins/glade/glade2ui.cpp
@@ -2181,7 +2181,7 @@ QStringList Glade2Ui::convertGladeFile( const QString& fileName )
outFileName += QString( ".ui" );
FILE *out = fopen( outFileName.latin1(), "w" );
if ( out == 0 ) {
- tqWarning( "glade2ui: Could not open file '%s'",
+ qWarning( "glade2ui: Could not open file '%s'",
outFileName.latin1() );
} else {
if ( !yyOut.isEmpty() )
diff --git a/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp b/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp
index 2934612..bce7fb2 100644
--- a/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp
+++ b/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp
@@ -251,7 +251,7 @@ bool KDEVDLG2UI::parse()
QString outputFile = QString( className ) + ".ui";
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) )
- tqFatal( "kdevdlg2ui: Could not open output file '%s'", outputFile.latin1() );
+ qFatal( "kdevdlg2ui: Could not open output file '%s'", outputFile.latin1() );
out = new QTextStream( &fileOut );
targetFiles.append( outputFile );
} else {
@@ -515,7 +515,7 @@ bool KDEVDLG2UI::writeDialog( const QString& name )
writeColor( "paletteBackgroundColor", color );
} //else {
//if ( line.length() )
- //tqDebug( "IGNORED: %s", line.latin1() );
+ //qDebug( "IGNORED: %s", line.latin1() );
//}
}
*out << "</UI>" << endl;
diff --git a/tools/designer/plugins/kdevdlg/main.cpp b/tools/designer/plugins/kdevdlg/main.cpp
index 6011ca0..1247f3d 100644
--- a/tools/designer/plugins/kdevdlg/main.cpp
+++ b/tools/designer/plugins/kdevdlg/main.cpp
@@ -89,7 +89,7 @@ QStringList KDevDlgFilter::import( const QString &, const QString& filename )
{
QFile file( filename );
if ( !file.open( IO_ReadOnly ) )
- tqWarning( "uic: Could not open file '%s' ", filename.latin1() );
+ qWarning( "uic: Could not open file '%s' ", filename.latin1() );
QTextStream in;
in.setDevice( &file );
diff --git a/tools/designer/plugins/rc/main.cpp b/tools/designer/plugins/rc/main.cpp
index b3900a9..f2e9abb 100644
--- a/tools/designer/plugins/rc/main.cpp
+++ b/tools/designer/plugins/rc/main.cpp
@@ -87,7 +87,7 @@ QStringList RCFilter::import( const QString &, const QString& filename )
{
QFile file( filename );
if ( !file.open( IO_ReadOnly ) )
- tqWarning( "uic: Could not open file '%s' ", filename.latin1() );
+ qWarning( "uic: Could not open file '%s' ", filename.latin1() );
QTextStream in;
in.setDevice( &file );
diff --git a/tools/designer/plugins/rc/rc2ui.cpp b/tools/designer/plugins/rc/rc2ui.cpp
index 0f27730..b3e48dd 100644
--- a/tools/designer/plugins/rc/rc2ui.cpp
+++ b/tools/designer/plugins/rc/rc2ui.cpp
@@ -380,7 +380,7 @@ bool RC2UI::makeDialog()
QString outputFile = QString(className) + ".ui";
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) )
- tqFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
+ qFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
out = new QTextStream( &fileOut );
targetFiles.append( outputFile );
} else {
@@ -838,7 +838,7 @@ bool RC2UI::makeStringTable()
if (outputFile ) {
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) )
- tqFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
+ qFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
out = new QTextStream( &fileOut );
}
diff --git a/tools/designer/plugins/cppeditor/yyreg.cpp b/tools/designer/plugins/cppeditor/yyreg.cpp
index 0648e36..144c99f 100644
--- a/tools/designer/plugins/cppeditor/yyreg.cpp
+++ b/tools/designer/plugins/cppeditor/yyreg.cpp
@@ -71,7 +71,7 @@ enum { Tok_Boi, Tok_Ampersand, Tok_Aster, Tok_LeftParen, Tok_RightParen,
/*
The following variables store the lexical analyzer state. The best way
to understand them is to implement a function myGetToken() that calls
- getToken(), to add some tqDebug() statements in there and then to
+ getToken(), to add some qDebug() statements in there and then to
#define getToken() myGetToken().
*/
static QString *yyIn; // the input stream
@@ -143,7 +143,7 @@ static void stopTokenizer()
*/
static int getToken()
{
// why "+ 2"? try putting some tqDebug()'s and see
yyPos = yyCurPos + 2;
for ( ;; ) {
@@ -177,7 +177,7 @@ static int getToken()
around with the tokenizer state to effectively
ignore the comment. Beware of off-by-one and
off-by-two bugs when you modify this code by adding
- tqDebug()'s here and there.
+ qDebug()'s here and there.
*/
if ( yyCurPos >= 0 ) {
int lineStart = yyIn->findRev( QChar('\n'), yyCurPos ) + 1;
@@ -143,7 +143,7 @@ static void stopTokenizer()
static int getToken()
{
- // why "+ 2"? try putting some tqDebug()'s and see
+ // why "+ 2"? try putting some qDebug()'s and see
yyPos = yyCurPos + 2;
for ( ;; ) {